==> glademm_0.6.4.orig.tar.gz: glademm-0.6.4/src/writers/menushell.cc <==
// $Id: menushell.cc,v 1.13 2001/10/11 14:07:24 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "container.hh"

class Gtk_MenuShell : public Gtk_Container
{public:
	typedef Gtk_Container Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_MenuShell();
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_MenuShell Gtk_MenuShell;

const std::string Gtk_MenuShell::TypeName(const Widget &w) const
{  return GtkPrefix()+"MenuShell";
}

const std::string Gtk_MenuShell::IncludeName(const Widget &w) const
{  return "gtk--/menushell.h";
}

Gtk_MenuShell::Gtk_MenuShell()
{  Writer["GtkMenuShell"]=this;
}

//#warning this code is untested

==> glademm_2.0.0.1.orig.tar.gz: glademm-2.0.0.1/src/writers/menushell.cc <==
// $Id: menushell.cc,v 1.15 2002/05/27 16:58:10 christof Exp $
/*  glade--: C++ frontend for glade (Gtk+ User Interface Builder)
 *  Copyright (C) 1999-2000  Adolf Petig GmbH & Co. KG, written by Christof Petig
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "container.hh"

// Widget addition code is in menubar.cc

class Gtk_MenuShell : public Gtk_Container
{public:
	typedef Gtk_Container Parent;
	virtual const std::string TypeName(const Widget &w) const;
	virtual const std::string IncludeName(const Widget &w) const;
	Gtk_MenuShell();
	virtual bool NeedExplicitCtor(const Widget &w) const
	{  return false; }
	virtual void ConstructionArgs(Widget const &w, CxxFile &f) const
	{  f.FunctionArg(); }
};

static Gtk_MenuShell Gtk_MenuShell;

const std::string Gtk_MenuShell::TypeName(const Widget &w) const
{  return GtkPrefix()+"MenuShell";
}

const std::string Gtk_MenuShell::IncludeName(const Widget &w) const
{  return Configuration.GtkmmIncludePath()+"menushell.h";
}

Gtk_MenuShell::Gtk_MenuShell()
{  Writer["GtkMenuShell"]=this;
}

//#warning this code is untested
